## Pipeline


<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/pipeline.py#L54)</span>
### Pipeline

```python
kipoi.pipeline.Pipeline(model, dataloader_cls)
```

Provides the predict_example, predict and predict_generator to the kipoi.Model

